Interface: InteractionModeMap | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: InteractionModeMap

## # Properties

### # dataset

• dataset: `InteractionModeFunction`

Returns items in the same dataset. If the options.intersect parameter is true, we only return items if we intersect something If the options.intersect is false, we find the nearest item and return the items in that dataset

#### # Defined in

index.esm.d.ts:732
(opens new window)

### # index

• index: `InteractionModeFunction`

Returns items at the same index. If the options.intersect parameter is true, we only return items if we intersect something If the options.intersect mode is false, we find the nearest item and return the items at the same index as that item

#### # Defined in

index.esm.d.ts:726
(opens new window)

### # nearest

• nearest: `InteractionModeFunction`

nearest mode returns the element closest to the point

#### # Defined in

index.esm.d.ts:741
(opens new window)

### # point

• point: `InteractionModeFunction`

Point mode returns all elements that hit test based on the event position of the event

#### # Defined in

index.esm.d.ts:737
(opens new window)

### # x

• x: `InteractionModeFunction`

x mode returns the elements that hit-test at the current x coordinate

#### # Defined in

index.esm.d.ts:745
(opens new window)

### # y

• y: `InteractionModeFunction`

y mode returns the elements that hit-test at the current y coordinate

#### # Defined in

index.esm.d.ts:749
(opens new window)